/*******************************************************************************
* File Name: MODEM.h
* Version 2.50
*
* Description:
*  Contains the function prototypes and constants available to the UART
*  user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/


#if !defined(CY_UART_MODEM_H)
#define CY_UART_MODEM_H

#include "cyfitter.h"
#include "cytypes.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */


/***************************************
* Conditional Compilation Parameters
***************************************/

#define MODEM_RX_ENABLED                     (1u)
#define MODEM_TX_ENABLED                     (1u)
#define MODEM_HD_ENABLED                     (0u)
#define MODEM_RX_INTERRUPT_ENABLED           (0u)
#define MODEM_TX_INTERRUPT_ENABLED           (0u)
#define MODEM_INTERNAL_CLOCK_USED            (1u)
#define MODEM_RXHW_ADDRESS_ENABLED           (0u)
#define MODEM_OVER_SAMPLE_COUNT              (8u)
#define MODEM_PARITY_TYPE                    (0u)
#define MODEM_PARITY_TYPE_SW                 (0u)
#define MODEM_BREAK_DETECT                   (0u)
#define MODEM_BREAK_BITS_TX                  (13u)
#define MODEM_BREAK_BITS_RX                  (13u)
#define MODEM_TXCLKGEN_DP                    (1u)
#define MODEM_USE23POLLING                   (1u)
#define MODEM_FLOW_CONTROL                   (0u)
#define MODEM_CLK_FREQ                       (0u)
#define MODEM_TX_BUFFER_SIZE                 (4u)
#define MODEM_RX_BUFFER_SIZE                 (4u)

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component UART_v2_50 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

#if defined(MODEM_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG)
    #define MODEM_CONTROL_REG_REMOVED            (0u)
#else
    #define MODEM_CONTROL_REG_REMOVED            (1u)
#endif /* End MODEM_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */


/***************************************
*      Data Structure Definition
***************************************/

/* Sleep Mode API Support */
typedef struct MODEM_backupStruct_
{
    uint8 enableState;

    #if(MODEM_CONTROL_REG_REMOVED == 0u)
        uint8 cr;
    #endif /* End MODEM_CONTROL_REG_REMOVED */

} MODEM_BACKUP_STRUCT;


/***************************************
*       Function Prototypes
***************************************/

void MODEM_Start(void) ;
void MODEM_Stop(void) ;
uint8 MODEM_ReadControlRegister(void) ;
void MODEM_WriteControlRegister(uint8 control) ;

void MODEM_Init(void) ;
void MODEM_Enable(void) ;
void MODEM_SaveConfig(void) ;
void MODEM_RestoreConfig(void) ;
void MODEM_Sleep(void) ;
void MODEM_Wakeup(void) ;

/* Only if RX is enabled */
#if( (MODEM_RX_ENABLED) || (MODEM_HD_ENABLED) )

    #if (MODEM_RX_INTERRUPT_ENABLED)
        #define MODEM_EnableRxInt()  CyIntEnable (MODEM_RX_VECT_NUM)
        #define MODEM_DisableRxInt() CyIntDisable(MODEM_RX_VECT_NUM)
        CY_ISR_PROTO(MODEM_RXISR);
    #endif /* MODEM_RX_INTERRUPT_ENABLED */

    void MODEM_SetRxAddressMode(uint8 addressMode)
                                                           ;
    void MODEM_SetRxAddress1(uint8 address) ;
    void MODEM_SetRxAddress2(uint8 address) ;

    void  MODEM_SetRxInterruptMode(uint8 intSrc) ;
    uint8 MODEM_ReadRxData(void) ;
    uint8 MODEM_ReadRxStatus(void) ;
    uint8 MODEM_GetChar(void) ;
    uint16 MODEM_GetByte(void) ;
    uint8 MODEM_GetRxBufferSize(void)
                                                            ;
    void MODEM_ClearRxBuffer(void) ;

    /* Obsolete functions, defines for backward compatible */
    #define MODEM_GetRxInterruptSource   MODEM_ReadRxStatus

#endif /* End (MODEM_RX_ENABLED) || (MODEM_HD_ENABLED) */

/* Only if TX is enabled */
#if(MODEM_TX_ENABLED || MODEM_HD_ENABLED)

    #if(MODEM_TX_INTERRUPT_ENABLED)
        #define MODEM_EnableTxInt()  CyIntEnable (MODEM_TX_VECT_NUM)
        #define MODEM_DisableTxInt() CyIntDisable(MODEM_TX_VECT_NUM)
        #define MODEM_SetPendingTxInt() CyIntSetPending(MODEM_TX_VECT_NUM)
        #define MODEM_ClearPendingTxInt() CyIntClearPending(MODEM_TX_VECT_NUM)
        CY_ISR_PROTO(MODEM_TXISR);
    #endif /* MODEM_TX_INTERRUPT_ENABLED */

    void MODEM_SetTxInterruptMode(uint8 intSrc) ;
    void MODEM_WriteTxData(uint8 txDataByte) ;
    uint8 MODEM_ReadTxStatus(void) ;
    void MODEM_PutChar(uint8 txDataByte) ;
    void MODEM_PutString(const char8 string[]) ;
    void MODEM_PutArray(const uint8 string[], uint8 byteCount)
                                                            ;
    void MODEM_PutCRLF(uint8 txDataByte) ;
    void MODEM_ClearTxBuffer(void) ;
    void MODEM_SetTxAddressMode(uint8 addressMode) ;
    void MODEM_SendBreak(uint8 retMode) ;
    uint8 MODEM_GetTxBufferSize(void)
                                                            ;
    /* Obsolete functions, defines for backward compatible */
    #define MODEM_PutStringConst         MODEM_PutString
    #define MODEM_PutArrayConst          MODEM_PutArray
    #define MODEM_GetTxInterruptSource   MODEM_ReadTxStatus

#endif /* End MODEM_TX_ENABLED || MODEM_HD_ENABLED */

#if(MODEM_HD_ENABLED)
    void MODEM_LoadRxConfig(void) ;
    void MODEM_LoadTxConfig(void) ;
#endif /* End MODEM_HD_ENABLED */


/* Communication bootloader APIs */
#if defined(CYDEV_BOOTLOADER_IO_COMP) && ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_MODEM) || \
                                          (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))
    /* Physical layer functions */
    void    MODEM_CyBtldrCommStart(void) CYSMALL ;
    void    MODEM_CyBtldrCommStop(void) CYSMALL ;
    void    MODEM_CyBtldrCommReset(void) CYSMALL ;
    cystatus MODEM_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;
    cystatus MODEM_CyBtldrCommRead(uint8 pData[], uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;

    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_MODEM)
        #define CyBtldrCommStart    MODEM_CyBtldrCommStart
        #define CyBtldrCommStop     MODEM_CyBtldrCommStop
        #define CyBtldrCommReset    MODEM_CyBtldrCommReset
        #define CyBtldrCommWrite    MODEM_CyBtldrCommWrite
        #define CyBtldrCommRead     MODEM_CyBtldrCommRead
    #endif  /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_MODEM) */

    /* Byte to Byte time out for detecting end of block data from host */
    #define MODEM_BYTE2BYTE_TIME_OUT (25u)
    #define MODEM_PACKET_EOP         (0x17u) /* End of packet defined by bootloader */
    #define MODEM_WAIT_EOP_DELAY     (5u)    /* Additional 5ms to wait for End of packet */
    #define MODEM_BL_CHK_DELAY_MS    (1u)    /* Time Out quantity equal 1mS */

#endif /* CYDEV_BOOTLOADER_IO_COMP */


/***************************************
*          API Constants
***************************************/
/* Parameters for SetTxAddressMode API*/
#define MODEM_SET_SPACE      (0x00u)
#define MODEM_SET_MARK       (0x01u)

/* Status Register definitions */
#if( (MODEM_TX_ENABLED) || (MODEM_HD_ENABLED) )
    #if(MODEM_TX_INTERRUPT_ENABLED)
        #define MODEM_TX_VECT_NUM            (uint8)MODEM_TXInternalInterrupt__INTC_NUMBER
        #define MODEM_TX_PRIOR_NUM           (uint8)MODEM_TXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* MODEM_TX_INTERRUPT_ENABLED */

    #define MODEM_TX_STS_COMPLETE_SHIFT          (0x00u)
    #define MODEM_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
    #define MODEM_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #if(MODEM_TX_ENABLED)
        #define MODEM_TX_STS_FIFO_FULL_SHIFT     (0x02u)
    #else /* (MODEM_HD_ENABLED) */
        #define MODEM_TX_STS_FIFO_FULL_SHIFT     (0x05u)  /* Needs MD=0 */
    #endif /* (MODEM_TX_ENABLED) */

    #define MODEM_TX_STS_COMPLETE            (uint8)(0x01u << MODEM_TX_STS_COMPLETE_SHIFT)
    #define MODEM_TX_STS_FIFO_EMPTY          (uint8)(0x01u << MODEM_TX_STS_FIFO_EMPTY_SHIFT)
    #define MODEM_TX_STS_FIFO_FULL           (uint8)(0x01u << MODEM_TX_STS_FIFO_FULL_SHIFT)
    #define MODEM_TX_STS_FIFO_NOT_FULL       (uint8)(0x01u << MODEM_TX_STS_FIFO_NOT_FULL_SHIFT)
#endif /* End (MODEM_TX_ENABLED) || (MODEM_HD_ENABLED)*/

#if( (MODEM_RX_ENABLED) || (MODEM_HD_ENABLED) )
    #if(MODEM_RX_INTERRUPT_ENABLED)
        #define MODEM_RX_VECT_NUM            (uint8)MODEM_RXInternalInterrupt__INTC_NUMBER
        #define MODEM_RX_PRIOR_NUM           (uint8)MODEM_RXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* MODEM_RX_INTERRUPT_ENABLED */
    #define MODEM_RX_STS_MRKSPC_SHIFT            (0x00u)
    #define MODEM_RX_STS_BREAK_SHIFT             (0x01u)
    #define MODEM_RX_STS_PAR_ERROR_SHIFT         (0x02u)
    #define MODEM_RX_STS_STOP_ERROR_SHIFT        (0x03u)
    #define MODEM_RX_STS_OVERRUN_SHIFT           (0x04u)
    #define MODEM_RX_STS_FIFO_NOTEMPTY_SHIFT     (0x05u)
    #define MODEM_RX_STS_ADDR_MATCH_SHIFT        (0x06u)
    #define MODEM_RX_STS_SOFT_BUFF_OVER_SHIFT    (0x07u)

    #define MODEM_RX_STS_MRKSPC           (uint8)(0x01u << MODEM_RX_STS_MRKSPC_SHIFT)
    #define MODEM_RX_STS_BREAK            (uint8)(0x01u << MODEM_RX_STS_BREAK_SHIFT)
    #define MODEM_RX_STS_PAR_ERROR        (uint8)(0x01u << MODEM_RX_STS_PAR_ERROR_SHIFT)
    #define MODEM_RX_STS_STOP_ERROR       (uint8)(0x01u << MODEM_RX_STS_STOP_ERROR_SHIFT)
    #define MODEM_RX_STS_OVERRUN          (uint8)(0x01u << MODEM_RX_STS_OVERRUN_SHIFT)
    #define MODEM_RX_STS_FIFO_NOTEMPTY    (uint8)(0x01u << MODEM_RX_STS_FIFO_NOTEMPTY_SHIFT)
    #define MODEM_RX_STS_ADDR_MATCH       (uint8)(0x01u << MODEM_RX_STS_ADDR_MATCH_SHIFT)
    #define MODEM_RX_STS_SOFT_BUFF_OVER   (uint8)(0x01u << MODEM_RX_STS_SOFT_BUFF_OVER_SHIFT)
    #define MODEM_RX_HW_MASK                     (0x7Fu)
#endif /* End (MODEM_RX_ENABLED) || (MODEM_HD_ENABLED) */

/* Control Register definitions */
#define MODEM_CTRL_HD_SEND_SHIFT                 (0x00u) /* 1 enable TX part in Half Duplex mode */
#define MODEM_CTRL_HD_SEND_BREAK_SHIFT           (0x01u) /* 1 send BREAK signal in Half Duplez mode */
#define MODEM_CTRL_MARK_SHIFT                    (0x02u) /* 1 sets mark, 0 sets space */
#define MODEM_CTRL_PARITY_TYPE0_SHIFT            (0x03u) /* Defines the type of parity implemented */
#define MODEM_CTRL_PARITY_TYPE1_SHIFT            (0x04u) /* Defines the type of parity implemented */
#define MODEM_CTRL_RXADDR_MODE0_SHIFT            (0x05u)
#define MODEM_CTRL_RXADDR_MODE1_SHIFT            (0x06u)
#define MODEM_CTRL_RXADDR_MODE2_SHIFT            (0x07u)

#define MODEM_CTRL_HD_SEND               (uint8)(0x01u << MODEM_CTRL_HD_SEND_SHIFT)
#define MODEM_CTRL_HD_SEND_BREAK         (uint8)(0x01u << MODEM_CTRL_HD_SEND_BREAK_SHIFT)
#define MODEM_CTRL_MARK                  (uint8)(0x01u << MODEM_CTRL_MARK_SHIFT)
#define MODEM_CTRL_PARITY_TYPE_MASK      (uint8)(0x03u << MODEM_CTRL_PARITY_TYPE0_SHIFT)
#define MODEM_CTRL_RXADDR_MODE_MASK      (uint8)(0x07u << MODEM_CTRL_RXADDR_MODE0_SHIFT)

/* StatusI Register Interrupt Enable Control Bits. As defined by the Register map for the AUX Control Register */
#define MODEM_INT_ENABLE                         (0x10u)

/* Bit Counter (7-bit) Control Register Bit Definitions. As defined by the Register map for the AUX Control Register */
#define MODEM_CNTR_ENABLE                        (0x20u)

/*   Constants for SendBreak() "retMode" parameter  */
#define MODEM_SEND_BREAK                         (0x00u)
#define MODEM_WAIT_FOR_COMPLETE_REINIT           (0x01u)
#define MODEM_REINIT                             (0x02u)
#define MODEM_SEND_WAIT_REINIT                   (0x03u)

#define MODEM_OVER_SAMPLE_8                      (8u)
#define MODEM_OVER_SAMPLE_16                     (16u)

#define MODEM_BIT_CENTER                         (MODEM_OVER_SAMPLE_COUNT - 2u)

#define MODEM_FIFO_LENGTH                        (4u)
#define MODEM_NUMBER_OF_START_BIT                (1u)
#define MODEM_MAX_BYTE_VALUE                     (0xFFu)

/* 8X always for count7 implementation */
#define MODEM_TXBITCTR_BREAKBITS8X   ((MODEM_BREAK_BITS_TX * MODEM_OVER_SAMPLE_8) - 1u)
/* 8X or 16X for DP implementation */
#define MODEM_TXBITCTR_BREAKBITS ((MODEM_BREAK_BITS_TX * MODEM_OVER_SAMPLE_COUNT) - 1u)

#define MODEM_HALF_BIT_COUNT   \
                            (((MODEM_OVER_SAMPLE_COUNT / 2u) + (MODEM_USE23POLLING * 1u)) - 2u)
#if (MODEM_OVER_SAMPLE_COUNT == MODEM_OVER_SAMPLE_8)
    #define MODEM_HD_TXBITCTR_INIT   (((MODEM_BREAK_BITS_TX + \
                            MODEM_NUMBER_OF_START_BIT) * MODEM_OVER_SAMPLE_COUNT) - 1u)

    /* This parameter is increased on the 2 in 2 out of 3 mode to sample voting in the middle */
    #define MODEM_RXBITCTR_INIT  ((((MODEM_BREAK_BITS_RX + MODEM_NUMBER_OF_START_BIT) \
                            * MODEM_OVER_SAMPLE_COUNT) + MODEM_HALF_BIT_COUNT) - 1u)

#else /* MODEM_OVER_SAMPLE_COUNT == MODEM_OVER_SAMPLE_16 */
    #define MODEM_HD_TXBITCTR_INIT   ((8u * MODEM_OVER_SAMPLE_COUNT) - 1u)
    /* 7bit counter need one more bit for OverSampleCount = 16 */
    #define MODEM_RXBITCTR_INIT      (((7u * MODEM_OVER_SAMPLE_COUNT) - 1u) + \
                                                      MODEM_HALF_BIT_COUNT)
#endif /* End MODEM_OVER_SAMPLE_COUNT */

#define MODEM_HD_RXBITCTR_INIT                   MODEM_RXBITCTR_INIT


/***************************************
* Global variables external identifier
***************************************/

extern uint8 MODEM_initVar;
#if (MODEM_TX_INTERRUPT_ENABLED && MODEM_TX_ENABLED)
    extern volatile uint8 MODEM_txBuffer[MODEM_TX_BUFFER_SIZE];
    extern volatile uint8 MODEM_txBufferRead;
    extern uint8 MODEM_txBufferWrite;
#endif /* (MODEM_TX_INTERRUPT_ENABLED && MODEM_TX_ENABLED) */
#if (MODEM_RX_INTERRUPT_ENABLED && (MODEM_RX_ENABLED || MODEM_HD_ENABLED))
    extern uint8 MODEM_errorStatus;
    extern volatile uint8 MODEM_rxBuffer[MODEM_RX_BUFFER_SIZE];
    extern volatile uint8 MODEM_rxBufferRead;
    extern volatile uint8 MODEM_rxBufferWrite;
    extern volatile uint8 MODEM_rxBufferLoopDetect;
    extern volatile uint8 MODEM_rxBufferOverflow;
    #if (MODEM_RXHW_ADDRESS_ENABLED)
        extern volatile uint8 MODEM_rxAddressMode;
        extern volatile uint8 MODEM_rxAddressDetected;
    #endif /* (MODEM_RXHW_ADDRESS_ENABLED) */
#endif /* (MODEM_RX_INTERRUPT_ENABLED && (MODEM_RX_ENABLED || MODEM_HD_ENABLED)) */


/***************************************
* Enumerated Types and Parameters
***************************************/

#define MODEM__B_UART__AM_SW_BYTE_BYTE 1
#define MODEM__B_UART__AM_SW_DETECT_TO_BUFFER 2
#define MODEM__B_UART__AM_HW_BYTE_BY_BYTE 3
#define MODEM__B_UART__AM_HW_DETECT_TO_BUFFER 4
#define MODEM__B_UART__AM_NONE 0

#define MODEM__B_UART__NONE_REVB 0
#define MODEM__B_UART__EVEN_REVB 1
#define MODEM__B_UART__ODD_REVB 2
#define MODEM__B_UART__MARK_SPACE_REVB 3



/***************************************
*    Initial Parameter Constants
***************************************/

/* UART shifts max 8 bits, Mark/Space functionality working if 9 selected */
#define MODEM_NUMBER_OF_DATA_BITS    ((8u > 8u) ? 8u : 8u)
#define MODEM_NUMBER_OF_STOP_BITS    (1u)

#if (MODEM_RXHW_ADDRESS_ENABLED)
    #define MODEM_RX_ADDRESS_MODE    (0u)
    #define MODEM_RX_HW_ADDRESS1     (0u)
    #define MODEM_RX_HW_ADDRESS2     (0u)
#endif /* (MODEM_RXHW_ADDRESS_ENABLED) */

#define MODEM_INIT_RX_INTERRUPTS_MASK \
                                  (uint8)((1 << MODEM_RX_STS_FIFO_NOTEMPTY_SHIFT) \
                                        | (0 << MODEM_RX_STS_MRKSPC_SHIFT) \
                                        | (0 << MODEM_RX_STS_ADDR_MATCH_SHIFT) \
                                        | (0 << MODEM_RX_STS_PAR_ERROR_SHIFT) \
                                        | (0 << MODEM_RX_STS_STOP_ERROR_SHIFT) \
                                        | (0 << MODEM_RX_STS_BREAK_SHIFT) \
                                        | (0 << MODEM_RX_STS_OVERRUN_SHIFT))

#define MODEM_INIT_TX_INTERRUPTS_MASK \
                                  (uint8)((0 << MODEM_TX_STS_COMPLETE_SHIFT) \
                                        | (0 << MODEM_TX_STS_FIFO_EMPTY_SHIFT) \
                                        | (0 << MODEM_TX_STS_FIFO_FULL_SHIFT) \
                                        | (0 << MODEM_TX_STS_FIFO_NOT_FULL_SHIFT))


/***************************************
*              Registers
***************************************/

#ifdef MODEM_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define MODEM_CONTROL_REG \
                            (* (reg8 *) MODEM_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG )
    #define MODEM_CONTROL_PTR \
                            (  (reg8 *) MODEM_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG )
#endif /* End MODEM_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */

#if(MODEM_TX_ENABLED)
    #define MODEM_TXDATA_REG          (* (reg8 *) MODEM_BUART_sTX_TxShifter_u0__F0_REG)
    #define MODEM_TXDATA_PTR          (  (reg8 *) MODEM_BUART_sTX_TxShifter_u0__F0_REG)
    #define MODEM_TXDATA_AUX_CTL_REG  (* (reg8 *) MODEM_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define MODEM_TXDATA_AUX_CTL_PTR  (  (reg8 *) MODEM_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define MODEM_TXSTATUS_REG        (* (reg8 *) MODEM_BUART_sTX_TxSts__STATUS_REG)
    #define MODEM_TXSTATUS_PTR        (  (reg8 *) MODEM_BUART_sTX_TxSts__STATUS_REG)
    #define MODEM_TXSTATUS_MASK_REG   (* (reg8 *) MODEM_BUART_sTX_TxSts__MASK_REG)
    #define MODEM_TXSTATUS_MASK_PTR   (  (reg8 *) MODEM_BUART_sTX_TxSts__MASK_REG)
    #define MODEM_TXSTATUS_ACTL_REG   (* (reg8 *) MODEM_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)
    #define MODEM_TXSTATUS_ACTL_PTR   (  (reg8 *) MODEM_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)

    /* DP clock */
    #if(MODEM_TXCLKGEN_DP)
        #define MODEM_TXBITCLKGEN_CTR_REG        \
                                        (* (reg8 *) MODEM_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define MODEM_TXBITCLKGEN_CTR_PTR        \
                                        (  (reg8 *) MODEM_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define MODEM_TXBITCLKTX_COMPLETE_REG    \
                                        (* (reg8 *) MODEM_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
        #define MODEM_TXBITCLKTX_COMPLETE_PTR    \
                                        (  (reg8 *) MODEM_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
    #else     /* Count7 clock*/
        #define MODEM_TXBITCTR_PERIOD_REG    \
                                        (* (reg8 *) MODEM_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define MODEM_TXBITCTR_PERIOD_PTR    \
                                        (  (reg8 *) MODEM_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define MODEM_TXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) MODEM_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define MODEM_TXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) MODEM_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define MODEM_TXBITCTR_COUNTER_REG   \
                                        (* (reg8 *) MODEM_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
        #define MODEM_TXBITCTR_COUNTER_PTR   \
                                        (  (reg8 *) MODEM_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
    #endif /* MODEM_TXCLKGEN_DP */

#endif /* End MODEM_TX_ENABLED */

#if(MODEM_HD_ENABLED)

    #define MODEM_TXDATA_REG             (* (reg8 *) MODEM_BUART_sRX_RxShifter_u0__F1_REG )
    #define MODEM_TXDATA_PTR             (  (reg8 *) MODEM_BUART_sRX_RxShifter_u0__F1_REG )
    #define MODEM_TXDATA_AUX_CTL_REG     (* (reg8 *) MODEM_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)
    #define MODEM_TXDATA_AUX_CTL_PTR     (  (reg8 *) MODEM_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define MODEM_TXSTATUS_REG           (* (reg8 *) MODEM_BUART_sRX_RxSts__STATUS_REG )
    #define MODEM_TXSTATUS_PTR           (  (reg8 *) MODEM_BUART_sRX_RxSts__STATUS_REG )
    #define MODEM_TXSTATUS_MASK_REG      (* (reg8 *) MODEM_BUART_sRX_RxSts__MASK_REG )
    #define MODEM_TXSTATUS_MASK_PTR      (  (reg8 *) MODEM_BUART_sRX_RxSts__MASK_REG )
    #define MODEM_TXSTATUS_ACTL_REG      (* (reg8 *) MODEM_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define MODEM_TXSTATUS_ACTL_PTR      (  (reg8 *) MODEM_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End MODEM_HD_ENABLED */

#if( (MODEM_RX_ENABLED) || (MODEM_HD_ENABLED) )
    #define MODEM_RXDATA_REG             (* (reg8 *) MODEM_BUART_sRX_RxShifter_u0__F0_REG )
    #define MODEM_RXDATA_PTR             (  (reg8 *) MODEM_BUART_sRX_RxShifter_u0__F0_REG )
    #define MODEM_RXADDRESS1_REG         (* (reg8 *) MODEM_BUART_sRX_RxShifter_u0__D0_REG )
    #define MODEM_RXADDRESS1_PTR         (  (reg8 *) MODEM_BUART_sRX_RxShifter_u0__D0_REG )
    #define MODEM_RXADDRESS2_REG         (* (reg8 *) MODEM_BUART_sRX_RxShifter_u0__D1_REG )
    #define MODEM_RXADDRESS2_PTR         (  (reg8 *) MODEM_BUART_sRX_RxShifter_u0__D1_REG )
    #define MODEM_RXDATA_AUX_CTL_REG     (* (reg8 *) MODEM_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define MODEM_RXBITCTR_PERIOD_REG    (* (reg8 *) MODEM_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define MODEM_RXBITCTR_PERIOD_PTR    (  (reg8 *) MODEM_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define MODEM_RXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) MODEM_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define MODEM_RXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) MODEM_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define MODEM_RXBITCTR_COUNTER_REG   (* (reg8 *) MODEM_BUART_sRX_RxBitCounter__COUNT_REG )
    #define MODEM_RXBITCTR_COUNTER_PTR   (  (reg8 *) MODEM_BUART_sRX_RxBitCounter__COUNT_REG )

    #define MODEM_RXSTATUS_REG           (* (reg8 *) MODEM_BUART_sRX_RxSts__STATUS_REG )
    #define MODEM_RXSTATUS_PTR           (  (reg8 *) MODEM_BUART_sRX_RxSts__STATUS_REG )
    #define MODEM_RXSTATUS_MASK_REG      (* (reg8 *) MODEM_BUART_sRX_RxSts__MASK_REG )
    #define MODEM_RXSTATUS_MASK_PTR      (  (reg8 *) MODEM_BUART_sRX_RxSts__MASK_REG )
    #define MODEM_RXSTATUS_ACTL_REG      (* (reg8 *) MODEM_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define MODEM_RXSTATUS_ACTL_PTR      (  (reg8 *) MODEM_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End  (MODEM_RX_ENABLED) || (MODEM_HD_ENABLED) */

#if(MODEM_INTERNAL_CLOCK_USED)
    /* Register to enable or disable the digital clocks */
    #define MODEM_INTCLOCK_CLKEN_REG     (* (reg8 *) MODEM_IntClock__PM_ACT_CFG)
    #define MODEM_INTCLOCK_CLKEN_PTR     (  (reg8 *) MODEM_IntClock__PM_ACT_CFG)

    /* Clock mask for this clock. */
    #define MODEM_INTCLOCK_CLKEN_MASK    MODEM_IntClock__PM_ACT_MSK
#endif /* End MODEM_INTERNAL_CLOCK_USED */


/***************************************
*       Register Constants
***************************************/

#if(MODEM_TX_ENABLED)
    #define MODEM_TX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End MODEM_TX_ENABLED */

#if(MODEM_HD_ENABLED)
    #define MODEM_TX_FIFO_CLR            (0x02u) /* FIFO1 CLR */
#endif /* End MODEM_HD_ENABLED */

#if( (MODEM_RX_ENABLED) || (MODEM_HD_ENABLED) )
    #define MODEM_RX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End  (MODEM_RX_ENABLED) || (MODEM_HD_ENABLED) */


/***************************************
* The following code is DEPRECATED and
* should not be used in new projects.
***************************************/

/* UART v2_40 obsolete definitions */
#define MODEM_WAIT_1_MS      MODEM_BL_CHK_DELAY_MS   

#define MODEM_TXBUFFERSIZE   MODEM_TX_BUFFER_SIZE
#define MODEM_RXBUFFERSIZE   MODEM_RX_BUFFER_SIZE

#if (MODEM_RXHW_ADDRESS_ENABLED)
    #define MODEM_RXADDRESSMODE  MODEM_RX_ADDRESS_MODE
    #define MODEM_RXHWADDRESS1   MODEM_RX_HW_ADDRESS1
    #define MODEM_RXHWADDRESS2   MODEM_RX_HW_ADDRESS2
    /* Backward compatible define */
    #define MODEM_RXAddressMode  MODEM_RXADDRESSMODE
#endif /* (MODEM_RXHW_ADDRESS_ENABLED) */

/* UART v2_30 obsolete definitions */
#define MODEM_initvar                    MODEM_initVar

#define MODEM_RX_Enabled                 MODEM_RX_ENABLED
#define MODEM_TX_Enabled                 MODEM_TX_ENABLED
#define MODEM_HD_Enabled                 MODEM_HD_ENABLED
#define MODEM_RX_IntInterruptEnabled     MODEM_RX_INTERRUPT_ENABLED
#define MODEM_TX_IntInterruptEnabled     MODEM_TX_INTERRUPT_ENABLED
#define MODEM_InternalClockUsed          MODEM_INTERNAL_CLOCK_USED
#define MODEM_RXHW_Address_Enabled       MODEM_RXHW_ADDRESS_ENABLED
#define MODEM_OverSampleCount            MODEM_OVER_SAMPLE_COUNT
#define MODEM_ParityType                 MODEM_PARITY_TYPE

#if( MODEM_TX_ENABLED && (MODEM_TXBUFFERSIZE > MODEM_FIFO_LENGTH))
    #define MODEM_TXBUFFER               MODEM_txBuffer
    #define MODEM_TXBUFFERREAD           MODEM_txBufferRead
    #define MODEM_TXBUFFERWRITE          MODEM_txBufferWrite
#endif /* End MODEM_TX_ENABLED */
#if( ( MODEM_RX_ENABLED || MODEM_HD_ENABLED ) && \
     (MODEM_RXBUFFERSIZE > MODEM_FIFO_LENGTH) )
    #define MODEM_RXBUFFER               MODEM_rxBuffer
    #define MODEM_RXBUFFERREAD           MODEM_rxBufferRead
    #define MODEM_RXBUFFERWRITE          MODEM_rxBufferWrite
    #define MODEM_RXBUFFERLOOPDETECT     MODEM_rxBufferLoopDetect
    #define MODEM_RXBUFFER_OVERFLOW      MODEM_rxBufferOverflow
#endif /* End MODEM_RX_ENABLED */

#ifdef MODEM_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define MODEM_CONTROL                MODEM_CONTROL_REG
#endif /* End MODEM_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */

#if(MODEM_TX_ENABLED)
    #define MODEM_TXDATA                 MODEM_TXDATA_REG
    #define MODEM_TXSTATUS               MODEM_TXSTATUS_REG
    #define MODEM_TXSTATUS_MASK          MODEM_TXSTATUS_MASK_REG
    #define MODEM_TXSTATUS_ACTL          MODEM_TXSTATUS_ACTL_REG
    /* DP clock */
    #if(MODEM_TXCLKGEN_DP)
        #define MODEM_TXBITCLKGEN_CTR        MODEM_TXBITCLKGEN_CTR_REG
        #define MODEM_TXBITCLKTX_COMPLETE    MODEM_TXBITCLKTX_COMPLETE_REG
    #else     /* Count7 clock*/
        #define MODEM_TXBITCTR_PERIOD        MODEM_TXBITCTR_PERIOD_REG
        #define MODEM_TXBITCTR_CONTROL       MODEM_TXBITCTR_CONTROL_REG
        #define MODEM_TXBITCTR_COUNTER       MODEM_TXBITCTR_COUNTER_REG
    #endif /* MODEM_TXCLKGEN_DP */
#endif /* End MODEM_TX_ENABLED */

#if(MODEM_HD_ENABLED)
    #define MODEM_TXDATA                 MODEM_TXDATA_REG
    #define MODEM_TXSTATUS               MODEM_TXSTATUS_REG
    #define MODEM_TXSTATUS_MASK          MODEM_TXSTATUS_MASK_REG
    #define MODEM_TXSTATUS_ACTL          MODEM_TXSTATUS_ACTL_REG
#endif /* End MODEM_HD_ENABLED */

#if( (MODEM_RX_ENABLED) || (MODEM_HD_ENABLED) )
    #define MODEM_RXDATA                 MODEM_RXDATA_REG
    #define MODEM_RXADDRESS1             MODEM_RXADDRESS1_REG
    #define MODEM_RXADDRESS2             MODEM_RXADDRESS2_REG
    #define MODEM_RXBITCTR_PERIOD        MODEM_RXBITCTR_PERIOD_REG
    #define MODEM_RXBITCTR_CONTROL       MODEM_RXBITCTR_CONTROL_REG
    #define MODEM_RXBITCTR_COUNTER       MODEM_RXBITCTR_COUNTER_REG
    #define MODEM_RXSTATUS               MODEM_RXSTATUS_REG
    #define MODEM_RXSTATUS_MASK          MODEM_RXSTATUS_MASK_REG
    #define MODEM_RXSTATUS_ACTL          MODEM_RXSTATUS_ACTL_REG
#endif /* End  (MODEM_RX_ENABLED) || (MODEM_HD_ENABLED) */

#if(MODEM_INTERNAL_CLOCK_USED)
    #define MODEM_INTCLOCK_CLKEN         MODEM_INTCLOCK_CLKEN_REG
#endif /* End MODEM_INTERNAL_CLOCK_USED */

#define MODEM_WAIT_FOR_COMLETE_REINIT    MODEM_WAIT_FOR_COMPLETE_REINIT

#endif  /* CY_UART_MODEM_H */


/* [] END OF FILE */
